<?php

class ShowBankPage extends AbstractGamePage
{
	public static $requireModule = 0;
	private $commission = 3;

	public function __construct(){
		parent::__construct();
	}

	private function bank_commission($ammount, $commission){
		return $ammount - ($ammount * ($commission / 100));
	}

	private function have_account(){
		global $USER;

		$db	 = Database::get();

		$query = "SELECT * FROM uni1_bank WHERE user_id=:user_id;";
		$response = $db->selectSingle($query, [':user_id' => $USER['id']]);

		return ($response)?true:false;
	}

	private function give_me_my_account(){
		global $USER;

		$db	 = Database::get();

		$query = "SELECT * FROM uni1_bank WHERE user_id=:user_id;";
		$response = $db->selectSingle($query, [':user_id' => $USER['id']]);

		return $response;
	}

	public function depositar(){
		global $USER, $PLANET, $LNG;

		$LNG->includeData(array('BANK'));

		$metal			= abs(HTTP::_GP('metal', 0));
		$crystal		= abs(HTTP::_GP('crystal', 0));
		$deuterium		= abs(HTTP::_GP('deuterium', 0));
		$dark_matter	= abs(HTTP::_GP('dark_matter', 0));

		$db	 = Database::get();


		if(empty($metal) && empty($crystal) && empty($deuterium) && empty($dark_matter)){
			$this->printMessage($LNG['no_0_depot']);
		}

		if($PLANET['metal'] < $metal || $PLANET['crystal'] < $crystal || $PLANET['deuterium'] < $deuterium || $USER['darkmatter'] < $dark_matter){
			$this->printMessage($LNG['no_resources_in_planet']);
		}

		$depos_metal 		= $this->bank_commission($metal, $this->commission);
		$depos_crystal 		= $this->bank_commission($crystal, $this->commission);
		$depos_deuterium 	= $this->bank_commission($deuterium, $this->commission);
		$depos_dark_matter 	= $this->bank_commission($dark_matter, $this->commission);

		$have_account 		= $this->have_account($USER['id']);

		if($have_account){
			$bank_account = $this->give_me_my_account();

			$rest_time = strtotime('-24 hours');

			if($bank_account['last_operation'] > $rest_time)
				$this->printMessage($LNG['no_time']);
		}

		$query = ($have_account)?"UPDATE ":"INSERT INTO ";

		$query .= "uni1_bank SET 
			metal = metal + :metal,
			crystal = crystal + :crystal,
			deuterium = deuterium + :deuterium,
			dark_matter = dark_matter + :dark_matter,
			last_operation = :time";

		$query .= ($have_account)?" WHERE user_id=:user_id;":" ,user_id=:user_id;";

		if (!$have_account) {
			$db->insert($query, [
				':metal' => $metal,
				':crystal' => $crystal,
				':deuterium' => $deuterium,
				':dark_matter' => $dark_matter,
				':time' => TIMESTAMP,
				':user_id' => $USER['id'],
			]);
		} else {
			$db->update($query, [
				':metal' => $metal,
				':crystal' => $crystal,
				':deuterium' => $deuterium,
				':dark_matter' => $dark_matter,
				':time' => TIMESTAMP,
				':user_id' => $USER['id'],
			]);
		}

		$PLANET['metal'] 		-= $metal;
		$PLANET['crystal'] 		-= $crystal;
		$PLANET['deuterium'] 	-= $deuterium;
		$USER['darkmatter'] 	-= $dark_matter;

		$this->printMessage($LNG['depot_ok']);
	}

	public function extraer(){
		global $USER, $PLANET, $LNG;

		$LNG->includeData(array('BANK'));

		$metal			= abs(HTTP::_GP('metal', 0));
		$crystal		= abs(HTTP::_GP('crystal', 0));
		$deuterium		= abs(HTTP::_GP('deuterium', 0));
		$dark_matter	= abs(HTTP::_GP('dark_matter', 0));

		$db	 = Database::get();

		if(!$this->have_account()){
			$this->printMessage($LNG['no_account']);
		}

		if(empty($metal) && empty($crystal) && empty($deuterium) && empty($dark_matter)){
			$this->printMessage($LNG['no_0_debit']);
		}

		$bank_account = $this->give_me_my_account();

		$rest_time = strtotime('-24 hours');

		if($bank_account['last_operation'] > $rest_time)
			$this->printMessage($LNG['no_time']);

		if($bank_account['metal'] < $metal || $bank_account['crystal'] < $crystal || $bank_account['deuterium'] < $deuterium || $bank_account['dark_matter'] < $dark_matter){
			$this->printMessage($LNG['no_resources_in_bank']);
		}

		$query = "UPDATE uni1_bank SET 
			metal = metal - :metal,
			crystal = crystal - :crystal,
			deuterium = deuterium - :deuterium,
			dark_matter = dark_matter - :dark_matter,
			last_operation = :time_operation
			WHERE user_id=:user_id;";

		$db->update($query, [
			':metal' => $metal,
			':crystal' => $crystal,
			':deuterium' => $deuterium,
			':dark_matter' => $dark_matter,
			':user_id' => $USER['id'],
			':time_operation' => TIMESTAMP
		]);

		$PLANET['metal'] 		+= $metal;
		$PLANET['crystal'] 		+= $crystal;
		$PLANET['deuterium'] 	+= $deuterium;
		$USER['darkmatter'] 	+= $dark_matter;

		$this->printMessage($LNG['debit_ok']);
	}

	public function show(){
		global $USER, $LNG, $PLANET;

		$PlanetRess	= new ResourceUpdate();
		$db	 = Database::get();

		$LNG->includeData(array('BANK'));

		if($this->have_account()){
			$resources = $this->give_me_my_account();
		}

		$bank_data = array(
			'metal' 		=> ($this->have_account())?$resources['metal']:0,
			'crystal' 		=> ($this->have_account())?$resources['crystal']:0,
			'deuterium' 	=> ($this->have_account())?$resources['deuterium']:0,
			'dark_matter' 	=> ($this->have_account())?$resources['dark_matter']:0,
		);

		$time = ($this->have_account())?$resources['last_operation']:0;

		$rest_time = strtotime('-24 hours');
		
		$this->assign(array(
			'bank_resources' 	=> $bank_data,
			'access_granted'	=> ($time < $rest_time)?true:false,
			'time'				=> $time + (3600 * 24),
			'commission_bank'	=> $this->commission,
			'LNG'				=> $LNG,
		));

		$this->display('bank_mod/page.bank.default.tpl');
	}

}